#
# spec file for package pmemkv
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pmemkv
Version:        1.5.0
Release:        1.3
Summary:        Key/Value Datastore for Persistent Memory
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://pmem.io/pmdk/
Source:         https://github.com/pmem/pmemkv/archive/%{version}.tar.gz
Patch1:         pmemkv-fix-gcc13-support.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libpmemobj-cpp-devel >= 1.11
BuildRequires:  libpmemobj-devel >= 1.8
BuildRequires:  memkind-devel >= 1.8.0
BuildRequires:  pkgconfig
BuildRequires:  pmdk-tools >= 1.8
BuildRequires:  pkgconfig(RapidJSON)
ExclusiveArch:  x86_64 aarch64 ppc64le

%description
pmemkv is a local/embedded key-value datastore optimized for persistent memory.
Rather than being tied to a single language or backing implementation, `pmemkv`
provides different options for language bindings and storage engines.

%package -n libpmemkv1
Summary:        Key/Value Datastore for Persistent Memory
Group:          System/Libraries
Requires:       libpmemkv_json_config1 >= %{version}

%description -n libpmemkv1
pmemkv is a local/embedded key-value datastore optimized for persistent memory.
Rather than being tied to a single language or backing implementation, `pmemkv`
provides different options for language bindings and storage engines.

%package -n libpmemkv_json_config1
Summary:        Helper library for libpmemkv
Group:          System/Libraries

%description -n libpmemkv_json_config1
pmemkv is a local/embedded key-value datastore optimized for persistent memory.
Rather than being tied to a single language or backing implementation, `pmemkv`
provides different options for language bindings and storage engines.

%package devel
Summary:        Key/Value Datastore for Persistent Memory
Group:          Development/Libraries/C and C++
Requires:       libpmemkv1 >= %{version}
Requires:       libpmemkv_json_config1 >= %{version}
Requires:       libpmemobj++-devel >= 1.10

%description devel
This package contains the header files for libpmemkv and libpmemkv_json_config

%prep
%setup -q
%patch1

%build
# ENGINE_VCMAP needs package-config(tbb) which is currently not available
%cmake -DTESTS_USE_VALGRIND=0 -DENGINE_VCMAP=0
%make_build

%install
%cmake_install

%post   -n libpmemkv1 -p /sbin/ldconfig
%postun -n libpmemkv1 -p /sbin/ldconfig
%post   -n libpmemkv_json_config1 -p /sbin/ldconfig
%postun -n libpmemkv_json_config1 -p /sbin/ldconfig

%files -n libpmemkv1
%license LICENSE
%{_libdir}/libpmemkv.so.1*

%files -n libpmemkv_json_config1
%license LICENSE
%{_libdir}/libpmemkv_json_config.so.1*

%files devel
%doc ChangeLog
%{_includedir}/libpmemkv*.h
%{_includedir}/libpmemkv*.hpp
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libpmemkv.so
%{_libdir}/libpmemkv_json_config.so

%changelog
* Wed Mar 29 2023 Nicolas Morey <nicolas.morey@suse.com>
- Add pmemkv-fix-gcc13-support.patch for GCC13 support
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  - New features:
  * Introduce (optional) caching layer in radix engine. It can be enabled
    via config parameters
  * Add new config's flag - 'create_if_missing' to address the missing
    functionality.
  * If set, pmemkv tries to open the pool and creates it if missing.
    It's mutually exclusive with 'create_or_error_if_exists' flag
  - Bug fixes:
  * Return correct status for wrong parameters in pmemkv_config_from_json
  * Fix iterator::key() implementation to return the whole key, not only
    the part up to the first null-terminator
  * Return correct status from memkind-based engines on open failure
* Mon Feb 22 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable build on aarch64
* Mon Oct 26 2020 Christian Vögl <christian.voegl@suse.com>
- Update to version 1.3
  * Introduces a new experimental engine - radix (single-threaded
    sorted map, backed by libpmemobj-cpp's radix_tree container).
  * config setters with type safety for common config fields
  * stree engine optimization (single-threaded sorted map with
    custom comparator support)
  * fixed operator== in stree engine
  * fixed missing checks in move assignment operators
  * operator<< for pmem::kv::status
* Thu Oct 15 2020 Christian Vögl <christian.voegl@suse.com>
- Replaced pkgconfig Buildreqiures with direct Package dependencies,
  to fix build issues for SLES
- ran spec-cleaner
* Wed Jul 22 2020 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Initial packaging of v1.2 (jsc#SLE-13926)
